@@ -40,10 +40,10 @@ def __check_alias__(
 ):
 	present = "--create-alias" in sys.argv and cl1.get_argument("--create-alias") == alias
 	base = f"/usr/local/bin"
-	if not os.path.exists(base):
+	if not Files.exists(base):
 		base = f"/usr/bin/"
 	path = f"{base}/{alias}"
-	if present or not os.path.exists(path):
+	if present or not Files.exists(path):
 		file = f"""#!/usr/bin/env python3\nimport os, sys\npackage="{executable}"\nsys.argv.pop(0)\narguments = sys.argv\ns = ""\nfor i in arguments:\n	if s == "": \n		if " " in i: s = "'"+i+"'"\n		else: s = i\n	else: \n		if " " in i: s += " '"+i+"'"\n		else: s += " "+i\nos.system("python3 "+package+" "+s)"""
 
 		os.system(f"touch {path}")
